@@ -1,10 +1,10 @@
 class User:
     """Represents a MangaDex User."""
-    __slots__ = ("id", "username", "client")
+    __slots__ = ("id", "username", "roles", "client")
 
-    def __init__(self, data, rel, client):
+    def __init__(self, data, client):
         self.id = data.get("id")
         _attrs = data.get("attributes")
         self.username = _attrs.get("username")
-        self.client = rel  # Dummy assignment for the search helper to work properly. Does not affect the object.
+        self.roles = _attrs.get("roles", [])
         self.client = client
